@@ -16,6 +16,7 @@ import argparse
 import hmac
 import os
 import random
+import stat
 import string
 import sys
 
@@ -56,8 +57,24 @@ def generate_RSA(bits=4096):
 
 def genpwd(passwords_file, length, uuid_keys, ssh_keys, blank_keys,
            fernet_keys, hmac_md5_keys):
-    with open(passwords_file, 'r') as f:
-        passwords = yaml.safe_load(f.read())
+    try:
+        with open(passwords_file, 'r') as f:
+            passwords = yaml.safe_load(f.read())
+    except FileNotFoundError:
+        print(f"ERROR: Passwords file \"{passwords_file}\" is missing")
+        sys.exit(1)
+
+    if os.stat(passwords_file).st_mode & stat.S_IROTH:
+        print(f"WARNING: Passwords file \"{passwords_file}\" is"
+              " world-readable. The permissions will be changed.")
+
+    if os.stat(passwords_file).st_mode & stat.S_IWOTH:
+        print(f"WARNING: Passwords file \"{passwords_file}\" is"
+              " world-writeable. The permissions will be changed.")
+
+    if not isinstance(passwords, dict):
+        print("ERROR: Passwords file not in expected key/value format")
+        sys.exit(1)
 
     for k, v in passwords.items():
         if (k in ssh_keys and
@@ -88,7 +105,15 @@ def genpwd(passwords_file, length, uuid_keys, ssh_keys, blank_keys,
                     for n in range(length)
                 ])
 
-    with open(passwords_file, 'w') as f:
+    try:
+        os.remove(passwords_file)
+    except OSError:
+        pass
+
+    flags = os.O_WRONLY | os.O_CREAT | os.O_TRUNC
+    mode = 0o640
+
+    with os.fdopen(os.open(passwords_file, flags, mode=mode), 'w') as f:
         f.write(yaml.safe_dump(passwords, default_flow_style=False))
 
 
@@ -108,12 +133,12 @@ def main():
                  'gnocchi_project_id',
                  'gnocchi_resource_id',
                  'gnocchi_user_id',
-                 'designate_pool_id',
-                 'karbor_openstack_infra_id']
+                 'designate_pool_id']
 
     # SSH key pair
     ssh_keys = ['kolla_ssh_key', 'nova_ssh_key',
-                'keystone_ssh_key', 'bifrost_ssh_key']
+                'keystone_ssh_key', 'bifrost_ssh_key', 'octavia_amp_ssh_key',
+                'neutron_ssh_key']
 
     # If these keys are None, leave them as None
     blank_keys = ['docker_registry_password']
