@@ -29,9 +29,6 @@ function setup_openstack_clients {
     if [[ $SCENARIO == scenario_nfv ]]; then
         packages+=(python-tackerclient python-barbicanclient python-mistralclient)
     fi
-    if [[ $SCENARIO == monasca ]]; then
-        packages+=(python-monascaclient)
-    fi
     if [[ $SCENARIO == ovn ]]; then
         packages+=(python-octaviaclient)
     fi
@@ -48,15 +45,6 @@ function prepare_images {
         return
     fi
 
-    if [[ $BASE_DISTRO == "centos" ]] && [[ $BASE_DISTRO_MAJOR_VERSION -eq 9 ]]; then
-        sudo tee -a /etc/kolla/kolla-build.conf <<EOF
-
-[DEFAULT]
-base_tag = stream9
-EOF
-
-    fi
-
     if [[ $SCENARIO != "bifrost" ]]; then
         GATE_IMAGES="^cron,^fluentd,^glance,^haproxy,^keepalived,^keystone,^kolla-toolbox,^mariadb,^memcached,^neutron,^nova-,^openvswitch,^rabbitmq,^horizon,^heat,^placement"
     else
@@ -67,9 +55,13 @@ EOF
         GATE_IMAGES+=",^cinder"
     fi
 
+    if [[ $SCENARIO == "cells" ]]; then
+        GATE_IMAGES+=",^proxysql"
+    fi
+
     if [[ $SCENARIO == "zun" ]]; then
         GATE_IMAGES+=",^zun,^kuryr,^etcd,^cinder,^iscsid"
-        if [[ $BASE_DISTRO != "centos" ]]; then
+        if [[ $BASE_DISTRO != "centos" && $BASE_DISTRO != "rocky" ]]; then
             GATE_IMAGES+=",^tgtd"
         fi
     fi
@@ -106,11 +98,6 @@ EOF
         GATE_IMAGES="^cron,^fluentd,^grafana,^haproxy,^keepalived,^kolla-toolbox,^mariadb,^memcached,^opensearch,^prometheus,^rabbitmq"
     fi
 
-    if [[ $SCENARIO == "monasca" ]]; then
-        # FIXME(mgoddard): No need for OpenStack core images.
-        GATE_IMAGES+=",^elasticsearch,^grafana,^influxdb,^kafka,^kibana,^logstash,^monasca,^storm,^zookeeper"
-    fi
-
     if [[ $SCENARIO == "venus" ]]; then
         GATE_IMAGES="^cron,^elasticsearch,^fluentd,^haproxy,^keepalived,^keystone,^kolla-toolbox,^mariadb,^memcached,^rabbitmq,^venus"
     fi
@@ -148,7 +135,7 @@ setup_openstack_clients
 RAW_INVENTORY=/etc/kolla/inventory
 
 source $KOLLA_ANSIBLE_VENV_PATH/bin/activate
-kolla-ansible -i ${RAW_INVENTORY} -e ansible_user=$USER -vvv bootstrap-servers &> /tmp/logs/ansible/bootstrap-servers
+kolla-ansible -i ${RAW_INVENTORY} -vvv bootstrap-servers &> /tmp/logs/ansible/bootstrap-servers
 deactivate
 
 prepare_images
